@@ -312,10 +312,10 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
 	
 	# Detect the environment - replaces ./configure implicitely
 	# and store the options into a cache
-	from SCons.Options import Options
+	from SCons.Variables import Variables
 	cachefile=env['CACHEDIR']+'/kde.cache.py'
-	opts = Options(cachefile)
-	opts.AddOptions(
+	opts = Variables(cachefile)
+	opts.AddVariables(
 		( 'QTDIR', 'root of qt directory' ),
 		( 'QTLIBPATH', 'path to the qt libraries' ),
 		( 'QTINCLUDEPATH', 'path to the qt includes' ),
