@@ -412,10 +412,10 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
 	Builder = SCons.Builder.Builder
 	
 	# Detect the environment - replaces ./configure implicitely and store the options into a cache
-	from SCons.Options import Options
+	from SCons.Variables import Variables
 	cachefile=env['CACHEDIR']+'kde.cache.py'
-	opts = Options(cachefile)
-	opts.AddOptions(
+	opts = Variables(cachefile)
+	opts.AddVariables(
 		('PREFIX', 'root of the program installation'),
 
 		('QTDIR', 'root of qt directory'),
